# trie challenge repo

This repo contains all the work for my challenge. 

To read about the server-side of the challenge, the file server_README.md goes over how the server and REST API was built. The lambda_function.py file is also explained in that readme. 

To understand the CLI part of my project, you can look in the CLI_README.md file. This file goes over how to use the CLI and get it (available with pip). The tricli directory has all the code for the CLI and also has a /tests folder containing all testing files. 

The setup.py and .github/workflows are there to get the CLI to pip, so you can ignore them. 

Thank you, and enjoy!
